@@ -86,9 +86,13 @@
     #############
     Other Options
     #############
-    **--zero-ho**
-        Use if input BED file uses zero-based, half-open coordinates instead
-        of one-based, closed.
+    **--oneidx-start**
+        If set, indicates input BED regions are formatted as one-indexed, 
+        closed intervals, as opposed to the BED default of zero-based, 
+        half-open intervals. For example, the first million bases on a 
+        chromosome would be:
+            Zero-based, half-open: 0,1000000
+            One-based, closed:     1,1000000
     **--bed-column-index** *<start_col,end_col,chrom_col>*
         Comma-separated list of zero-based indexes of start, end, and 
         chromosome name columns in input BED file. Default value for
@@ -122,7 +126,7 @@ from pgpipe.misc import argprase_kwargs
 
 class locus():
     #Name, pops, store for seqs, length, mut model, scalar, mutrate
-    def __init__(self, gener, rec_list, popmodel, args):
+    def __init__(self, gener, rec_list, popmodel, args, snp_density = None):
         if args.inhet_sc is None:
             if gener.chrom in ['X','chrX']:
                 self.inhet_sc = 0.75
@@ -152,6 +156,8 @@ class locus():
         else:
             self.seq_len = len(rec_list)
         self.mutrate = self.gene_len * args.mutrate
+        if snp_density is not None and not args.no_density:
+            self.mutrate += args.mutrate / snp_density
 
     def addSeq(self,seq,pop):
         try:
@@ -218,8 +224,9 @@ def parseArguments(passed_arguments = []):
                         "pop model file"))
     parser.add_argument("--model",dest="poptag",help=("If model file has "
                         "multiple models, use model with this name"))
-    parser.add_argument("--zero-ho", dest="zeroho", action="store_true",
-                        help="Region coordinates are zero-based, half-open")
+    parser.add_argument('--oneidx-start',dest="oneidx", action="store_true",
+                        help=("Region list start coordinates indexed from 1, "
+                        "not 0"))
     parser.add_argument("--zero-closed", dest="zeroclosed",action="store_true",
                         help="Region coordinates are zero-based, closed")
     parser.add_argument("--keep-indels", dest="indel_flag", action="store_true",
@@ -269,6 +276,8 @@ def parseArguments(passed_arguments = []):
     parser.add_argument("--out-prefix",dest="multi_out",type=str,
                         help=("If output is fasta, generate one file"
                         "per loci."))
+    parser.add_argument('--no-density-header',dest="no_density",action="store_true",
+                        help=("If set, will not pull density info from VCF header"))
     if passed_arguments:
         return vars(parser.parse_args(passed_arguments))
     else:
@@ -486,9 +495,10 @@ def vcf_to_ima(**kwargs):
         Comma-separated list of length 3 with 0-based indexes of start, end,
         and chromosome data in input BED file. Default for normal BED is
         "1,2,0".
-    --zero-ho : bool
-        If set, treats regions in BED file as 0-based, (h)alf (o)pen
-        coordinates rather than 1-based, closed. 
+    --oneidx-start
+        If set, use human-readable coordinates for BED file (i.e. 1-100 for
+        first 100 bases in a genome) as opposed to default of zero-based, 
+        half-open (0-100).
     --out : str
         Name for output file. Defaults to 'input.ima.u"
     --remove-multiallele : bool
@@ -582,7 +592,7 @@ def vcf_to_ima(**kwargs):
     regions_provided = False
     if args.genename is not None:
         regions_provided = True
-        region_list = RegionList(filename=args.genename, zeroho=args.zeroho,
+        region_list = RegionList(filename=args.genename, zeroho=(not args.oneidx),
                             zeroclosed=args.zeroclosed,
                             colstr=args.gene_col)
         logging.info('Region list read')
@@ -603,6 +613,7 @@ def vcf_to_ima(**kwargs):
     for i in range(total_regions):
         #if regions_provided:
         #region = region_list.regions[i]
+        snp_density = None
         if args.multi_out is not None:
             try:
                 output_file.close()
@@ -619,6 +630,7 @@ def vcf_to_ima(**kwargs):
                                       popmodel=popmodel,
                                       use_allpop=use_allpop)
             rec_list = vcf_reader.getRecordList()
+            snp_density = vcf_reader.getSnpDensityFromHeader()
             vcf_reader.reader.close()
             if regions_provided:
                 region = region_list.regions[i]
@@ -641,7 +653,7 @@ def vcf_to_ima(**kwargs):
                 ref_seq = fasta_ref.fetch(vf.flipChrom(region.chrom),region.start,region.end)
             checkRefAlign(rec_list, fasta_ref, region.chrom, args.ref_check)
         if not args.fasta:
-            temp_locus = locus(region, rec_list, popmodel, args)
+            temp_locus = locus(region, rec_list, popmodel, args, snp_density=snp_density)
             #reg_header = getLocusHeader(region, popmodel, rec_list,mut_rate=args.mutrate,inhet_sc=args.inhet_sc,include_seq=(fasta_ref is not None))
             #output_file.write(reg_header+'\n')
         popnum = 0
